@@ -334,12 +334,6 @@ def is_valid_file(parser, arg):
 
 
 def get_parser():
-    PROJECT_ROOT = utils.get_project_root()
-
-    # Get latest model folder
-    models_folder = os.path.join(PROJECT_ROOT, "models")
-    latest_model = utils.get_latest_folder(models_folder)
-
     from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
     parser = ArgumentParser(description=__doc__,
                             formatter_class=ArgumentDefaultsHelpFormatter)
@@ -348,7 +342,7 @@ def get_parser():
                         help="where is the model folder (with the info.yml)?",
                         metavar="FOLDER",
                         type=lambda x: utils.is_valid_folder(parser, x),
-                        default=latest_model)
+                        default=utils.default_model(__file__))
     parser.add_argument("-s", "--set",
                         dest="aset",
                         choices=['test', 'train', 'valid'],
