@@ -305,3 +305,19 @@ def get_readable_time(t):
         return "%is %ims" % (s, ms)
     else:
         return "%ims" % ms
+
+
+def default_model(scriptfile):
+    """Get a path for a default value for the model.
+
+    scriptfile should be __file__ of the calling script
+    """
+    PROJECT_ROOT = get_project_root()
+    models_dir = os.path.join(PROJECT_ROOT, "models")
+    curr_dir = os.path.dirname(os.path.realpath(scriptfile))
+    if os.path.commonprefix([models_dir, curr_dir]) == models_dir and \
+       curr_dir != models_dir:
+        latest_model = get_latest_model(curr_dir)
+    else:
+        latest_model = get_latest_folder(models_dir)
+    return latest_model
